Glossary — Pyblosxom 1.5 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyblosxom 1.5 documentation »

# Glossary

flavour

  A flavour is a group of templates for a specifc output like html, xhtml, xml, atom, rss, etc.

  A flavour consists of at least the following templates:

  - content_type - holds the content type of the flavour
  - head - holds everything before all the entries
  - story - holds a single entry
  - foot - holds everything after all the entries
  - date_head - shows at the start of a date
  - date_foot - shows at the end of a date

  See Flavours and Templates for more details.

template

  A template specifies a specific portion of the output.

  For example, here’s a head template for an html flavour:

      <html>
      <head>
        <title>My blog</title>
      </head>
      <body>

  See Flavours and Templates for more details.

### Navigation

- index
- modules |
- next |
- previous |
- Pyblosxom 1.5 documentation »